/*********************************************************************/
/* Copyright (c) 2013, EPFL/Blue Brain Project                       */
/*                     Raphael Dumusc <raphael.dumusc@epfl.ch>       */
/* All rights reserved.                                              */
/*                                                                   */
/* Redistribution and use in source and binary forms, with or        */
/* without modification, are permitted provided that the following   */
/* conditions are met:                                               */
/*                                                                   */
/*   1. Redistributions of source code must retain the above         */
/*      copyright notice, this list of conditions and the following  */
/*      disclaimer.                                                  */
/*                                                                   */
/*   2. Redistributions in binary form must reproduce the above      */
/*      copyright notice, this list of conditions and the following  */
/*      disclaimer in the documentation and/or other materials       */
/*      provided with the distribution.                              */
/*                                                                   */
/*    THIS  SOFTWARE IS PROVIDED  BY THE  UNIVERSITY OF  TEXAS AT    */
/*    AUSTIN  ``AS IS''  AND ANY  EXPRESS OR  IMPLIED WARRANTIES,    */
/*    INCLUDING, BUT  NOT LIMITED  TO, THE IMPLIED  WARRANTIES OF    */
/*    MERCHANTABILITY  AND FITNESS FOR  A PARTICULAR  PURPOSE ARE    */
/*    DISCLAIMED.  IN  NO EVENT SHALL THE UNIVERSITY  OF TEXAS AT    */
/*    AUSTIN OR CONTRIBUTORS BE  LIABLE FOR ANY DIRECT, INDIRECT,    */
/*    INCIDENTAL,  SPECIAL, EXEMPLARY,  OR  CONSEQUENTIAL DAMAGES    */
/*    (INCLUDING, BUT  NOT LIMITED TO,  PROCUREMENT OF SUBSTITUTE    */
/*    GOODS  OR  SERVICES; LOSS  OF  USE,  DATA,  OR PROFITS;  OR    */
/*    BUSINESS INTERRUPTION) HOWEVER CAUSED  AND ON ANY THEORY OF    */
/*    LIABILITY, WHETHER  IN CONTRACT, STRICT  LIABILITY, OR TORT    */
/*    (INCLUDING NEGLIGENCE OR OTHERWISE)  ARISING IN ANY WAY OUT    */
/*    OF  THE  USE OF  THIS  SOFTWARE,  EVEN  IF ADVISED  OF  THE    */
/*    POSSIBILITY OF SUCH DAMAGE.                                    */
/*                                                                   */
/* The views and conclusions contained in the software and           */
/* documentation are those of the authors and should not be          */
/* interpreted as representing official policies, either expressed   */
/* or implied, of The University of Texas at Austin.                 */
/*********************************************************************/

#include "PDFInteractionDelegate.h"
#include "configuration/Configuration.h"
#include "ContentWindow.h"
#include "PDFContent.h"
#include "globals.h"

#include <QTapGesture>
#include <QSwipeGesture>

PDFInteractionDelegate::PDFInteractionDelegate(ContentWindow& contentWindow)
    : ZoomInteractionDelegate(contentWindow)
{
    assert(contentWindow_.getContent()->getType() == CONTENT_TYPE_PDF);
}


void PDFInteractionDelegate::tap(QTapGesture *gesture)
{
    if ( gesture->state() == Qt::GestureFinished )
    {
        double x, y, w, h;
        contentWindow_.getCoordinates(x, y, w, h);

        double winCenterX = (x + 0.5 * w) * g_configuration->getTotalWidth();

        if (gesture->position().x() > winCenterX)
            getPDFContent()->nextPage();
        else
            getPDFContent()->previousPage();
    }
}

PDFContent *PDFInteractionDelegate::getPDFContent()
{
    return static_cast<PDFContent*>(contentWindow_.getContent().get());
}


void PDFInteractionDelegate::swipe(QSwipeGesture *gesture)
{
    if (gesture->horizontalDirection() == QSwipeGesture::Left)
    {
        getPDFContent()->previousPage();
    }
    else if (gesture->horizontalDirection() == QSwipeGesture::Right)
    {
        getPDFContent()->nextPage();
    }
}


